==> trip-0.1.0.tar.gz: trip-0.1.0/util/VThreadGate.cxx <==

/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF ,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */





static const char* const VThreadGate_cxx_Version =
    "$Id: VThreadGate.cxx,v 1.4 2000/09/20 08:01:35 cvs Exp $";
#include "VThreadGate.hxx"

VThreadGate::VThreadGate(void)
{
    pthread_mutex_init(&structure_lock, NULL);
    pthread_cond_init(&wakeup, NULL);
    closed = 1;
}

VThreadGate::~VThreadGate(void)
{
    pthread_mutex_destroy(&structure_lock);
    pthread_cond_destroy(&wakeup);
}

void
VThreadGate::Open(void)
{
    pthread_mutex_lock(&structure_lock);
    closed = 0;
    pthread_cond_broadcast(&wakeup);
    pthread_mutex_unlock(&structure_lock);
}

void
VThreadGate::Close(void)
{
    pthread_mutex_lock(&structure_lock);
    closed = 1;
    pthread_mutex_unlock(&structure_lock);
}

// temporarily open the gate, allowing any waiting threads to
// proceed
void
VThreadGate::Release(void)
{
    pthread_cond_broadcast(&wakeup);
}
void
VThreadGate::Wait(void)
{
    pthread_mutex_lock(&structure_lock);
    if (closed)
    {
        pthread_cond_wait(&wakeup, &structure_lock);
    }
    pthread_mutex_unlock(&structure_lock);
}

==> trip-1.0.0.tar.gz: trip-1.0.0/util/VThreadGate.cxx <==
/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF $1,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */

static const char* const VThreadGate_cxx_Version =
    "$Id: VThreadGate.cxx,v 1.6 2001/01/23 22:40:55 bko Exp $";

#include "VThreadGate.hxx"


VThreadGate::VThreadGate()
{
    pthread_mutex_init(&structure_lock, NULL);
    pthread_cond_init(&wakeup, NULL);
    closed = 1;
}


VThreadGate::~VThreadGate()
{
    pthread_mutex_destroy(&structure_lock);
    pthread_cond_destroy(&wakeup);
}


void
VThreadGate::Open()
{
    pthread_mutex_lock(&structure_lock);
    closed = 0;
    pthread_cond_broadcast(&wakeup);
    pthread_mutex_unlock(&structure_lock);
}


void
VThreadGate::Close()
{
    pthread_mutex_lock(&structure_lock);
    closed = 1;
    pthread_mutex_unlock(&structure_lock);
}


// temporarily open the gate, allowing any waiting threads to
// proceed
void
VThreadGate::Release()
{
    pthread_cond_broadcast(&wakeup);
}


void
VThreadGate::Wait()
{
    pthread_mutex_lock(&structure_lock);
    if (closed)
    {
        pthread_cond_wait(&wakeup, &structure_lock);
    }
    pthread_mutex_unlock(&structure_lock);
}
